package com.i2asolutions.admob;


import com.aerserv.sdk.AerServConfig;
import com.aerserv.sdk.AerServEvent;
import com.aerserv.sdk.AerServEventListener;
import com.aerserv.sdk.AerServInterstitial;
import com.google.android.gms.ads.AdRequest;
import com.google.android.gms.ads.mediation.MediationAdRequest;
import com.google.android.gms.ads.mediation.customevent.CustomEventInterstitial;
import com.google.android.gms.ads.mediation.customevent.CustomEventInterstitialListener;

import android.content.Context;
import android.os.Bundle;
import android.util.Log;

import java.util.ArrayList;
import java.util.List;

/**
 * A custom event for the Sample ad network. Custom events allow publishers to write their own
 * mediation adapter.
 */
public final class AdmobCustomEventInterstitial implements CustomEventInterstitial {

    AerServInterstitial aerServInterstitial;



    @Override
    public void requestInterstitialAd(Context context,
                                      CustomEventInterstitialListener customEventInterstitialListener,
                                      String s,
                                      MediationAdRequest mediationAdRequest,
                                      Bundle bundle) {
        Log.i("1000741:",s);
        List<String> keywords;
        if(mediationAdRequest.getKeywords() != null)
        {
            keywords = new ArrayList<>(mediationAdRequest.getKeywords());
        }
        else
        {
            keywords = new ArrayList<>();
        }

        final AerServConfig config = new AerServConfig(context, s).setKeywords(keywords)
                .setEventListener(new AerserInterstitalForwarder(context, customEventInterstitialListener)).setDebug(true);
        aerServInterstitial = new AerServInterstitial(config);
        customEventInterstitialListener.onAdLoaded();
    }

    @Override
    public void showInterstitial() {
        if (aerServInterstitial != null) {
            aerServInterstitial.show();
        }
    }


    @Override
    public void onDestroy() {
        if(aerServInterstitial != null){
            aerServInterstitial.kill();
            Log.i("AD:", "DESTROY:");
        }
    }

    @Override
    public void onPause() {
        if(aerServInterstitial != null)
        {
            aerServInterstitial.pause();
        }
    }

    @Override
    public void onResume() {
        if(aerServInterstitial != null)
        {
            aerServInterstitial.play();
        }
    }

    public class AerserInterstitalForwarder implements AerServEventListener
    {

        private CustomEventInterstitialListener customEventInterstitiallistener;
        private Context context;

        public AerserInterstitalForwarder(Context context, CustomEventInterstitialListener customEventInterstitiallistener)
        {
            this.context = context;
            this.customEventInterstitiallistener = customEventInterstitiallistener;
        }


        @Override
        public void onAerServEvent(final AerServEvent aerServEvent, final List<Object> list) {
            ((MainActivity) context).runOnUiThread(new Runnable() {
                @Override
                public void run() {
                    switch (aerServEvent)
                    {
                        case AD_LOADED:
                            //customEventInterstitiallistener.onAdLoaded();
                            break;

                        case AD_FAILED:
                            //Displaying error message
                            //Log.i("ERROR:", list.get(0).toString());
                            //Sending default 0 to inform about error has occured
                            customEventInterstitiallistener.onAdFailedToLoad(0);
                            break;

                        case AD_CLICKED:
                            customEventInterstitiallistener.onAdClicked();
                            customEventInterstitiallistener.onAdLeftApplication();
                            break;

                        case AD_DISMISSED:
                            customEventInterstitiallistener.onAdClosed();
                            break;

                        case AD_IMPRESSION:

                    }
                }
            });

        }
    }
}
